@@ -8,7 +8,7 @@ use Carp;
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 sub holidays {
     croak "holidays is unimplemented for ".__PACKAGE__;
@@ -60,7 +60,7 @@ Date::Holidays::Adapter::JP - an adapter class for Date::Japanese::Holiday
 
 =head1 VERSION
 
-This POD describes version 1.09 of Date::Holidays::Adapter::JP
+This POD describes version 1.10 of Date::Holidays::Adapter::JP
 
 =head1 DESCRIPTION
 
@@ -120,13 +120,7 @@ Please refer to BUGS AND LIMITATIONS in L<Date::Holidays>
 
 =head1 BUG REPORTING
 
-Please report issues via CPAN RT:
-
-  http://rt.cpan.org/NoAuth/Bugs.html?Dist=Date-Holidays
-
-or by sending mail to
-
-  bug-Date-Holidays@rt.cpan.org
+Please refer to BUG REPORTING in L<Date::Holidays>
 
 =head1 SEE ALSO
 
